@@ -37,6 +37,12 @@ THE SOFTWARE.
 #include <libxslt/xslt.h>
 #include <libxslt/xsltconfig.h>
 
+#ifdef _WIN32
+#  define WIN32_LEAN_AND_MEAN
+#  include <windows.h>
+#  include <shellapi.h>         /* CommandLineToArgvW() */
+#endif
+
 #include "xmlstar.h"
 
 gOptions globalOptions;
@@ -85,6 +91,7 @@ void
 gInitOptions(gOptionsPtr ops)
 {
     ops->quiet = 0;
+    ops->doc_namespace = 1;
 }
 
 /**
@@ -94,8 +101,8 @@ void reportGenericError(void* ctx, const char * msg, ...) {
     /* do nothing */
 }
 
-/* by default errors are reported */
-static ErrorInfo errorInfo = { NULL, NULL, VERBOSE };
+/* by default all errors are reported */
+static ErrorInfo errorInfo = { NULL, NULL, VERBOSE, CONTINUE };
 
 void reportError(void *ptr, xmlErrorPtr error)
 {
@@ -148,6 +155,9 @@ void reportError(void *ptr, xmlErrorPtr error)
             if (ctxt) xmlParserPrintFileContext(ctxt->input);
         }
     }
+    if (errorInfo->stop == STOP) {
+        exit(EXIT_FAILURE);
+    }
 }
 
 void
@@ -182,6 +192,38 @@ xstrdup(const char *str)
     return ret;
 }
 
+
+#ifdef _WIN32
+/* On Windows, it's not really practical to get argv in UTF-8, so we have to do
+   this little dance. */
+static void
+gGetUnicodeOptions(int argc, char **argv)
+{
+    int nArgs, i;
+    LPWSTR *szArglist = CommandLineToArgvW(GetCommandLineW(), &nArgs);
+    assert(nArgs == argc);
+
+    for (i = 0; i < argc; i++) {
+        char *utf;
+        int utflen = WideCharToMultiByte(CP_UTF8, 0,
+            szArglist[i], -1,
+            NULL, 0, NULL, NULL);
+        if (utflen <= 0) {
+            fprintf(stderr, "Error decoding argument %d\n", i);
+            exit(EXIT_BAD_ARGS);
+        }
+        utf = malloc(utflen);
+        WideCharToMultiByte(CP_UTF8, 0,
+            szArglist[i], -1,
+            utf, utflen, NULL, NULL);
+        argv[i] = utf;
+    }
+    LocalFree(szArglist);
+}
+#else
+#  define gGetUnicodeOptions(argc, argv)
+#endif
+
 /**
  *  Parse global command line options
  */
@@ -197,6 +239,16 @@ gParseOptions(gOptionsPtr ops, int *argc, char **argv)
             ops->quiet = 1;
             i++;
         }
+        else if (!strcmp(argv[i], "--no-doc-namespace"))
+        {
+            ops->doc_namespace = 0;
+            i++;
+        }
+        else if (!strcmp(argv[i], "--doc-namespace"))
+        {
+            ops->doc_namespace = 1;
+            i++;
+        }
         else if (!strcmp(argv[i], "--version"))
         {
             fprintf(stdout, "%s\n"
@@ -240,7 +292,8 @@ main(int argc, char **argv)
     int ret = 0;
 
     xmlMemSetup(free, xmalloc, xrealloc, xstrdup);
-    
+
+    gGetUnicodeOptions(argc, argv);
     gInitOptions(&globalOptions);
     gParseOptions(&globalOptions, &argc, argv);
     
@@ -351,10 +404,6 @@ static void bad_ns_opt(const char *msg)
     exit(EXIT_BAD_ARGS);
 }
 
-const char* DEFAULT_NS_FAIL_MESSAGE =
-    "None of the XPaths matched; to match a node in the default namespace\n"
-    "use '_' as the prefix (see section 5.1 in the manual).\n"
-    "For instance, use /_:node instead of /node\n";
 const xmlChar *default_ns = NULL;
 
 #define MAX_NS_ARGS    256
