@@ -442,12 +442,10 @@ edMove(xmlDocPtr doc, xmlNodeSetPtr nodes, xmlNodePtr to)
 
 /**
  *  Loop through array of operations and perform them
- *  @return number of successful operations
  */
-static int
+static void
 edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
 {
-    int op_applied = 0;
     int k;
     xmlXPathContextPtr ctxt = xmlXPathNewContext(doc);
     /* NOTE: later registrations override earlier ones */
@@ -467,7 +465,8 @@ edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
     exsltStrXpathCtxtRegister(ctxt, BAD_CAST "str");
 #endif
     /* namespaces from doc */
-    extract_ns_defs(doc, ctxt);
+    if (globalOptions.doc_namespace)
+        extract_ns_defs(doc, ctxt);
     /* namespaces from command line */
     nsarr_xpath_register(ctxt);
 
@@ -490,8 +489,6 @@ edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
         if (!res || res->type != XPATH_NODESET || !res->nodesetval) continue;
         nodes = res->nodesetval;
 
-        op_applied += (nodes->nodeNr > 0);
-
         switch (ops[k].op)
         {
             case XML_ED_DELETE:
@@ -536,8 +533,6 @@ edProcess(xmlDocPtr doc, const XmlEdAction* ops, int ops_count)
     xmlDeregisterNodeDefault(NULL);
 
     xmlXPathFreeContext(ctxt);
-
-    return op_applied;
 }
 
 /**
@@ -547,7 +542,6 @@ static void
 edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
     const edOptions* g_ops)
 {
-    int op_applied;
     xmlDocPtr doc;
     int save_options =
 #if LIBXML_VERSION >= 20708
@@ -568,7 +562,7 @@ edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
         exit(EXIT_BAD_FILE);
     }
 
-    op_applied = edProcess(doc, ops, ops_count);
+    edProcess(doc, ops, ops_count);
 
     /* avoid getting ASCII CRs in UTF-16/UCS-(2,4) text */
     if ((xmlStrcasestr(doc->encoding, BAD_CAST "UTF") == 0
@@ -586,10 +580,6 @@ edOutput(const char* filename, const XmlEdAction* ops, int ops_count,
     xmlSaveDoc(save, doc);
     xmlSaveClose(save);
     xmlFreeDoc(doc);
-
-    if (!op_applied && ops_count > 0 && default_ns && !globalOptions.quiet) {
-        fprintf(stderr, DEFAULT_NS_FAIL_MESSAGE);
-    }
 }
 
 /**
