@@ -241,35 +241,25 @@ pyxUsage(const char *argv0, exit_status status)
     exit(status);
 }
 
-int
+static xmlSAXHandler pyxSAX;
+
+static int
 pyx_process_file(const char *filename)
 {
     int ret;
     xmlParserCtxtPtr ctxt;
 
-    xmlInitParser();
     ctxt = xmlCreateFileParserCtxt(filename);
+    if (!ctxt) /* assume it failed because of filename */
+        return EXIT_BAD_FILE;
 
-    memset(ctxt->sax, 0, sizeof(*ctxt->sax));
-
-    /* Establish Event Handlers */
-    ctxt->sax->initialized = XML_SAX2_MAGIC;
-    ctxt->sax->startElementNs = pyxStartElement;
-    ctxt->sax->endElementNs = pyxEndElement;
-    ctxt->sax->processingInstruction = pyxProcessingInstruction;
-    ctxt->sax->characters = pyxCharacterData;
-    ctxt->sax->notationDecl = pyxNotationDeclHandler;
-    ctxt->sax->reference = pyxExternalEntityReferenceHandler;
-    ctxt->sax->unparsedEntityDecl = pyxUnparsedEntityDeclHandler;
-    ctxt->sax->externalSubset = pyxExternalSubsetHandler;
-    ctxt->sax->comment = pyxCommentHandler;
-    ctxt->sax->cdataBlock = pyxCdataBlockHandler;
-
+    ctxt->sax = &pyxSAX;
     ret = xmlParseDocument(ctxt);
-    xmlFreeParserCtxt(ctxt);
-    xmlCleanupParser();
 
-    return ret;
+    ctxt->sax = NULL; /* don't try to free pyxSAX */
+    xmlFreeParserCtxt(ctxt);
+
+    return (ret == 0)? 0 : EXIT_LIB_ERROR;
 }
 
 int
@@ -288,6 +278,21 @@ pyxMain(int argc,const char *argv[])
     {
         pyxUsage(argv[0], EXIT_SUCCESS);
     }
+
+    xmlInitParser();
+    /* Establish Event Handlers */
+    pyxSAX.startElementNs = pyxStartElement;
+    pyxSAX.endElementNs = pyxEndElement;
+    pyxSAX.processingInstruction = pyxProcessingInstruction;
+    pyxSAX.characters = pyxCharacterData;
+    pyxSAX.notationDecl = pyxNotationDeclHandler;
+    pyxSAX.reference = pyxExternalEntityReferenceHandler;
+    pyxSAX.unparsedEntityDecl = pyxUnparsedEntityDeclHandler;
+    pyxSAX.externalSubset = pyxExternalSubsetHandler;
+    pyxSAX.comment = pyxCommentHandler;
+    pyxSAX.cdataBlock = pyxCdataBlockHandler;
+    pyxSAX.initialized = XML_SAX2_MAGIC;
+
     if (argc == 2) {
         status = pyx_process_file("-");
     }
@@ -299,5 +304,6 @@ pyxMain(int argc,const char *argv[])
             if (ret != 0) status = ret;
         }
     }
+    xmlCleanupParser();
     return status;
 }
