@@ -666,7 +666,8 @@ do_file(const char *filename, xmlDocPtr style_tree,
 
         static xsltStylesheetPtr style = NULL;
         if (!style) {
-            extract_ns_defs(xmlDocGetRootElement(doc), style_tree);
+            if (globalOptions.doc_namespace)
+                extract_ns_defs(xmlDocGetRootElement(doc), style_tree);
             /* Parse XSLT stylesheet */
             style = xsltParseStylesheetDoc(style_tree);
             if (!style) exit(EXIT_LIB_ERROR);
@@ -739,10 +740,6 @@ selMain(int argc, char **argv)
     if (i == argc)
         do_file("-", style_tree, xml_options, &ops, &xsltOps, &status);
 
-    if (status != EXIT_SUCCESS && default_ns && !ops.quiet) {
-        fprintf(stderr, DEFAULT_NS_FAIL_MESSAGE);
-    }
-
     /* 
      * Shutdown libxml
      */
