@@ -23,11 +23,13 @@ typedef enum { /* EXIT_SUCCESS = 0, EXIT_FAILURE = 1, */
 #define COUNT_OF(array) (sizeof(array)/sizeof(*array))
 
 typedef enum { QUIET, VERBOSE } Verbosity;
+typedef enum { CONTINUE, STOP } ErrorStop;
 
 typedef struct _errorInfo {
     const char *filename; /* file error occured in, if any, else NULL */
     xmlTextReaderPtr xmlReader;
     Verbosity verbose;
+    ErrorStop stop;
 } ErrorInfo;
 
 void reportError(void *ptr, xmlErrorPtr error);
@@ -35,6 +37,7 @@ void suppressErrors(void);
 
 typedef struct _gOptions {
     int quiet;            /* no error output */
+    int doc_namespace;   /* extract namespace bindings from input doc */
 } gOptions;
 
 typedef gOptions *gOptionsPtr;
@@ -45,7 +48,6 @@ void registerXstarVariable(xmlXPathContextPtr ctxt,
     const char* name, xmlXPathObjectPtr value);
 void registerXstarNs(xmlXPathContextPtr ctxt);
 
-const char* DEFAULT_NS_FAIL_MESSAGE;
 extern const xmlChar *default_ns;
 
 int parseNSArr(xmlChar** ns_arr, int* plen, int argc, char **argv);
